==> haskell-monadrandom-0.5.1.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MonadRandom
version: 0.5.1.1
id: MonadRandom-0.5.1.1-HPWQi2S7jojIGIrtYLRzjp
key: MonadRandom-0.5.1.1-HPWQi2S7jojIGIrtYLRzjp
license: BSD-3-Clause
maintainer: Brent Yorgey <byorgey@gmail.com>
author: Cale Gibbard and others
synopsis: Random-number generation monad.
description:
    Support for computations which consume random values.
category: Control
abi: 7138175d67ed4ff39d31b93cae4f33dd
exposed: True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict
import-dirs: /usr/lib/ghc-8.4.3/site-local/MonadRandom-0.5.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/MonadRandom-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/MonadRandom-0.5.1.1
hs-libraries: HSMonadRandom-0.5.1.1-HPWQi2S7jojIGIrtYLRzjp
depends:
    base-4.11.1.0 transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W mtl-2.2.2
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
haddock-interfaces: /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html: /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadrandom-0.5.1.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MonadRandom
version: 0.5.1.1
id: MonadRandom-0.5.1.1-CCvKXDVdRR27FxuQiLW1dF
key: MonadRandom-0.5.1.1-CCvKXDVdRR27FxuQiLW1dF
license: BSD-3-Clause
maintainer: Brent Yorgey <byorgey@gmail.com>
author: Cale Gibbard and others
synopsis: Random-number generation monad.
description:
    Support for computations which consume random values.
category: Control
abi: 6dd8f2d8300a2fc75ec3955a3cb0fb4b
exposed: True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict
import-dirs: /usr/lib/ghc-8.6.1/site-local/MonadRandom-0.5.1.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/MonadRandom-0.5.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/MonadRandom-0.5.1.1
hs-libraries: HSMonadRandom-0.5.1.1-CCvKXDVdRR27FxuQiLW1dF
depends:
    base-4.12.0.0 mtl-2.2.2 primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    random-1.1-3ypV4EIycgb35PKjTYYr5q transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
haddock-interfaces: /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html: /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
